# p5-python3-aiogoldsrcrcon
python3 asyncio rcon client for GoldSrc engine

## Install
- from Python Package Index (PyPI): `pip install p5.aiogoldsrcrcon`
- from source code directory: `cd path/to/source/code/directory && pip install .`
- from source code archive file: `pip install path/to/source/code/archive/file`


## Library
### Example
Watch [example.py](./example.py)

### Help
```
import p5.aiogoldsrcrcon
help(p5.aiogoldsrcrcon)
help(p5.aiogoldsrcrcon.connection)
help(p5.aiogoldsrcrcon.Connection)
```

## Binary entry point
`p5-aiogoldsrcrcon[.exe] --help`

Also, you can use portable exe with same interface on Windows: https://github.com/p5-vbnekit/p5-python3-aiogoldsrcrcon/releases/latest/download/p5-aiogoldsrcrcon-portable.exe
